@@ -4,27 +4,18 @@ import sys
 import os
 import getopt
 import argparse
+
+# SUB COMMONDS DEF[
+# https://docs.python.org/3/library/argparse.html#sub-commands
 from . import global_args
 from . import refmt
 from . import frosted
 from . import recolor
 from . import resize
-import sys
-
-# https://docs.python.org/3/library/argparse.html#sub-commands
-
-
-def add_global_argments(sub_parser):
-    sub_parser.add_argument('-i',
-                            '--infile',
-                            help='the file to be recolor')
-    sub_parser.add_argument('-r',
-                            '--recursive',
-                            action='store_true',
-                            help='recursive the input file')
-    sub_parser.add_argument('-o',
-                            '--outfile',
-                            help='Optional the output file')
+from . import text2icon
+from . import shadow
+# IMPORT SUBCMD DEF HERE
+# SUB COMMONDS DEF]
 
 
 def main():
@@ -40,10 +31,15 @@ def main():
         description='ezpp [subcommand] [options]',
         help='subcommand using:ezpp [subcommand] -h')
 
+    # SUB COMMONDS ARGMENTS[
     global_args.add_global_argments(frosted.create_cmd_parser(subparsers))
     global_args.add_global_argments(recolor.create_cmd_parser(subparsers))
     global_args.add_global_argments(resize.create_cmd_parser(subparsers))
     global_args.add_global_argments(refmt.create_cmd_parser(subparsers))
+    global_args.add_global_argments(text2icon.create_cmd_parser(subparsers))
+    global_args.add_global_argments(shadow.create_cmd_parser(subparsers))
+    # ADD SUBCMD ARGMENTS HERE
+    # SUB COMMONDS ARGMENTS]
 
     if len(sys.argv) < 2:
         parser.print_help()
