@@ -25,7 +25,8 @@ def repeat2(str_tobe_repeat):
 
 def _on_args_parsed(args):
     params = vars(args)
-    infile, outfile, recursive = global_args.parser_io_argments(params)
+    infile, outfile, recursive, overwrite = global_args.parser_io_argments(
+        params)
 
     sizeStr = params['size']
     if not sizeStr:
@@ -41,18 +42,18 @@ def _on_args_parsed(args):
         else:
             mode = 0
 
-        frosted(infile, outfile, recursive, size, mode)
+        frosted(infile, outfile, recursive, overwrite, size, mode)
     else:
-        frosted(infile, outfile, recursive)
+        frosted(infile, outfile, recursive, overwrite)
 
 
-def frosted(infile, outfile, recursive, blurSize=10, mode=5):
+def frosted(infile, outfile, recursive, overwrite, blurSize=10, mode=5):
     if recursive == None or recursive == False:
         return frosted_file(infile, outfile, blurSize, mode)
     infiles = global_args.get_recursive_pic_infiles(infile)
     for infile_for_recursive in infiles:
         frosted_file(infile_for_recursive,
-                     infile_for_recursive,
+                     infile_for_recursive if overwrite else None,
                      blurSize,
                      mode)
 
@@ -60,8 +61,7 @@ def frosted(infile, outfile, recursive, blurSize=10, mode=5):
 def frosted_file(infile, outfile, blurSize=10, mode=5):
     new_filename = outfile
     if outfile == None:
-        bar_filename, ext = os.path.splitext(infile)
-        new_filename = f"{bar_filename}_frosted{ext}"
+        new_filename = global_args.auto_outfile(infile, '_frosted')
 
     print(f"{infile} frosted(size = {blurSize}) -> {new_filename}")
 
