@@ -45,7 +45,7 @@ def create_cmd_parser(subparsers):
 def _on_args_parsed(args):
     params = vars(args)
     app = params['app']
-    infile, outfile, recursive = global_args.parser_io_argments(params)
+    infile, outfile, recursive, o = global_args.parser_io_argments(params)
     size = params['size']
 
     if app:
@@ -104,12 +104,11 @@ def on_size_parsed(infile, outfile, recursive, size):
     infiles = global_args.get_recursive_pic_infiles(infile)
     for infile_for_recursive in infiles:
         _on_size_parsed(infile_for_recursive,
-                        infile_for_recursive,
+                        None,
                         size)
 
 
 def _on_size_parsed(infile, outfile, size):
-
     with open(os.path.abspath(infile), 'rb') as imgfile:
         img = Image.open(imgfile)
         (origin_w, origin_h) = img.size
@@ -123,25 +122,27 @@ def _on_size_parsed(infile, outfile, size):
             new_width = int(origin_w * width)
             new_height = int(origin_h * height)
 
-        _resize(infile, outfile, origin_w, origin_h,
+        newFile = outfile
+        if outfile == None or outfile == Null:
+            newFile = global_args.auto_outfile(
+                infile, f"_{new_width}x{new_height}")
+
+        _resize(infile, newFile, origin_w, origin_h,
                 new_width, new_height, img)
 
 
 def _resize(infile, outfile, origin_w, origin_h, new_width, new_height, img):
-    bar_filename, ext = os.path.splitext(infile)
-    filename_new = outfile if outfile else f"{bar_filename}_{new_width}x{new_height}{ext}"
-
     print(f"resize: ({origin_w}, {origin_h})->({new_width}, {new_height})")
     print(f"from:   {os.path.abspath(infile)}")
-    print(f"to:     {os.path.abspath(filename_new)}")
+    print(f"to:     {os.path.abspath(outfile)}")
 
-    out_dir, filename = os.path.split(filename_new)
+    out_dir, filename = os.path.split(outfile)
     if len(out_dir) > 0 and not os.path.exists(out_dir):
         os.makedirs(out_dir)
 
     img_tobe_scale = img.resize(
         (int(new_width), int(new_height)), Image.ANTIALIAS)
-    img_tobe_scale.save(os.path.abspath(filename_new), 'PNG')
+    img_tobe_scale.save(os.path.abspath(outfile), 'PNG')
 
 
 def _copy(src_file, dst_file):
@@ -169,7 +170,7 @@ def _parse_wh_from_size(size, origin_w, origin_h):
     m_percent = re_percent.match(size)
     if m_percent:
         ratio = float(m_percent.group(1))/float(100)
-        return (origin_w*ratio, origin_h*ratio)
+        return (int(origin_w*ratio), int(origin_h*ratio))
     else:
         print(size_using)
         exit(2)
